@@ -40,10 +40,10 @@
 #include <QTimer>
 #include <QVersionNumber>
 
-#include <KActivities/Consumer>
-#include <KActivities/Stats/Cleaning>
-#include <KActivities/Stats/ResultSet>
-#include <KActivities/Stats/Terms>
+#include <PlasmaActivities/Consumer>
+#include <PlasmaActivities/Stats/Cleaning>
+#include <PlasmaActivities/Stats/ResultSet>
+#include <PlasmaActivities/Stats/Terms>
 
 #include <processcore/process.h>
 #include <processcore/processes.h>
